@@ -26,7 +26,9 @@ from twisted.python.deprecate import (
     deprecatedProperty,
 )
 
-from twisted.python.versions import Version
+from twisted.python.compat import _PY3
+from incremental import Version
+from twisted.python.runtime import platform
 from twisted.python.filepath import FilePath
 
 from twisted.python.test import deprecatedattributes
@@ -253,7 +255,7 @@ class ImportedModuleAttributeTests(TwistedModulesMixin, SynchronousTestCase):
 
     _packageInit = """\
 from twisted.python.deprecate import deprecatedModuleAttribute
-from twisted.python.versions import Version
+from incremental import Version
 
 deprecatedModuleAttribute(
     Version('Package', 1, 2, 3), 'message', __name__, 'module')
@@ -391,6 +393,12 @@ def callTestFunction():
         self.addCleanup(
             lambda: (sys.modules.clear(), sys.modules.update(modules)))
 
+        # On Windows on Python 3, most FilePath interactions produce
+        # DeprecationWarnings, so flush them here so that they don't interfere
+        # with the tests.
+        if platform.isWindows() and _PY3:
+            self.flushWarnings()
+
 
     def test_warning(self):
         """
@@ -469,7 +477,7 @@ def callTestFunction():
         self.addCleanup(sys.modules.pop, module.__name__)
 
         module.callTestFunction()
-        warningsShown = self.flushWarnings()
+        warningsShown = self.flushWarnings([module.testFunction])
         warnedPath = FilePath(warningsShown[0]["filename"].encode("utf-8"))
         expectedPath = self.package.sibling(
             b'twisted_renamed_helper').child(b'module.py')
